@@ -95,56 +95,33 @@ class DingtalkPluginEcool(CorePluginMixin, notify.NotificationPlugin):
         if not self.is_configured(project):
             return
 
-        title = event.title.encode("utf-8")
-        # TODO(dcramer): we'd like this to be the event culprit, but Sentry
-        # does not currently retain it
-        if group.culprit:
-            culprit = group.culprit.encode("utf-8")
-        else:
-            culprit = None
         project_name = project.get_full_name().encode("utf-8")
 
-        fields = []
-
-        # They can be the same if there is no culprit
-        # So we set culprit to an empty string instead of duplicating the text
-        if culprit and title != culprit:
-            fields.append(
-                {"title": "Culprit", "value": culprit, "short": False})
-        fields.append(
-            {"title": "Project", "value": project_name, "short": True})
-
+        # title
+        title = event.title.encode("utf-8")
         if self.get_option("custom_message", project):
-            fields.append(
-                {
-                    "title": "Custom message",
-                    "value": self.get_option("custom_message", project),
-                    "short": False,
-                }
-            )
+            title = "{} ({})".format(
+                title, self.get_option("custom_message", project))
 
+        # issue
+        issue_link = group.get_absolute_url(params={"referrer": "dingding"})
+        issueStr = "\n> #### [issue]({})".format(issue_link)
+
+        # 报警规则
+        ruleStr = ""
         if self.get_option("include_rules", project):
-            rules = []
-            for rule in notification.rules:
+            if notification.rules:
+                rule = notification.rules[0]
                 rule_link = "/%s/%s/settings/alerts/rules/%s/" % (
                     group.organization.slug,
                     project.slug,
                     rule.id,
                 )
-
-                # Make sure it's an absolute uri since we're sending this
-                # outside of Sentry into Slack
                 rule_link = absolute_uri(rule_link)
-                rules.append((rule_link, rule.label))
-
-            if rules:
-                value = u", ".join(u"<{} | {}>".format(*r) for r in rules)
-
-                fields.append(
-                    {"title": "Triggered By", "value": value.encode(
-                        "utf-8"), "short": False}
-                )
+                ruleStr = u"\n> 由报警规则[{}]({})触发".format(rule.label, rule_link)
 
+        # 标签
+        tagStr = ""
         if self.get_option("include_tags", project):
             included_tags = set(self.get_tag_list(
                 "included_tag_keys", project) or [])
@@ -155,31 +132,23 @@ class DingtalkPluginEcool(CorePluginMixin, notify.NotificationPlugin):
                 std_key = tagstore.get_standardized_key(key)
                 if included_tags and key not in included_tags and std_key not in included_tags:
                     continue
-                if excluded_tags and (key in excluded_tags or std_key in excluded_tags):
-                    continue
-                fields.append(
-                    {
-                        "title": tag_key.encode("utf-8"),
-                        "value": tag_value.encode("utf-8"),
-                        "short": True,
-                    }
-                )
-        payload = {
-            "attachments": [
-                {
-                    "fallback": "[%s] %s" % (project_name, title),
-                    "title": title,
-                    "title_link": group.get_absolute_url(params={"referrer": "slack"}),
-                    "fields": fields,
-                }
-            ]
-        }
+                tagStr = tagStr + \
+                    "\n> ###### {}:{} ".format(tag_key.encode(
+                        "utf-8"), tag_value.encode("utf-8"))
+
+        payload = title
+        if ruleStr:
+            payload = title + ruleStr
+        payload = payload + issueStr
+        if tagStr:
+            payload = payload + tagStr
 
         webhookUrl = self.get_option("webhook", project)
         headers = {'Content-type': 'application/json', 'Accept': 'text/plain'}
-        data = {"msgtype": "text",
-                "text": {
-                    "content": json.dumps(payload)
+        data = {"msgtype": "markdown",
+                "markdown": {
+                    "title": title,
+                    "text": json.dumps(payload)
                 }
                 }
         requests.post(webhookUrl, data=json.dumps(data), headers=headers)
